module.exports = defineTest({
	description: 'allows plugins to set options.entry',
	command: 'rollup -c --bundleConfigAsCjs'
});
